@@ -49,19 +49,20 @@
 #define MIOPEN_ENABLE_SQLITE_BACKOFF 1
 #define MIOPEN_USE_MLIR 1
 #define MIOPEN_USE_COMPOSABLEKERNEL 1
+#define MIOPEN_ENABLE_AI_IMMED_MODE_FALLBACK 1
 #define MIOPEN_ENABLE_AI_KERNEL_TUNING 1
 
 // "_PACKAGE_" to avoid name contentions: the macros like
 // HIP_VERSION_MAJOR are defined in hip_version.h.
 // clang-format off
-#define HIP_PACKAGE_VERSION_MAJOR 5
-#define HIP_PACKAGE_VERSION_MINOR 6
+#define HIP_PACKAGE_VERSION_MAJOR 6
+#define HIP_PACKAGE_VERSION_MINOR 0
 #define HIP_PACKAGE_VERSION_PATCH 0
 // clang-format on
 
 // clang-format off
 #define MIOPEN_AMD_COMGR_VERSION_MAJOR 2
-#define MIOPEN_AMD_COMGR_VERSION_MINOR 5
+#define MIOPEN_AMD_COMGR_VERSION_MINOR 6
 #define MIOPEN_AMD_COMGR_VERSION_PATCH 0
 // clang-format on
 
@@ -73,6 +74,8 @@
 //     remain in the future)  perform final conversion (and rounding) of FP32
 //     to BF16 results. This affects the main functionality of the library.
 #define MIOPEN_USE_RNE_BFLOAT16 1
+#define MIOPEN_FP8_IEEE_EXPONENT_BIAS 1
+#define MIOPEN_FP8_CLIPPING 1
 
 // clang-format off
 #define MIOPEN_DEFAULT_FIND_MODE DynamicHybrid
@@ -120,7 +123,7 @@
 
 #if MIOPEN_USE_ROCBLAS
 // clang-format off
-#define MIOPEN_ROCBLAS_VERSION_MAJOR 3
+#define MIOPEN_ROCBLAS_VERSION_MAJOR 4
 #define MIOPEN_ROCBLAS_VERSION_MINOR 0
 #define MIOPEN_ROCBLAS_VERSION_PATCH 0
 // clang-format on
@@ -152,6 +155,6 @@
 #include <hip/hip_version.h>
 #endif
 
-#define MIOPEN_GOLDEN_DB_VERSION -
+#define MIOPEN_GOLDEN_DB_VERSION 18
 
 #endif // GUARD_CONFIG_H_IN
